From 8ab3cdc09cfbac3157e996664616c229214f6c8d Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Fri, 21 Oct 2011 06:03:56 -0400
Subject: [PATCH] Merged revisions 2681-2739 from 3.0.4 stable branch.

---
 interface/web/sites/web_domain_del.php |   31 +++++++++++++++++++++++++++----
 1 files changed, 27 insertions(+), 4 deletions(-)

diff --git a/interface/web/sites/web_domain_del.php b/interface/web/sites/web_domain_del.php
index e5614cf..a69923f 100644
--- a/interface/web/sites/web_domain_del.php
+++ b/interface/web/sites/web_domain_del.php
@@ -55,29 +55,52 @@
 		
 		if($app->tform->checkPerm($this->id,'d') == false) $app->error($app->lng('error_no_delete_permission'));
 		
-		// Delete all records that belog to this zone.
+		//* Delete all records that belog to this zone.
 		$records = $app->db->queryAllRecords("SELECT domain_id FROM web_domain WHERE parent_domain_id = '".intval($this->id)."' AND type != 'vhost'");
 		foreach($records as $rec) {
 			$app->db->datalogDelete('web_domain','domain_id',$rec['domain_id']);
 		}
 		
-		// Delete all records that belog to this zone.
+		//* Delete all records that belog to this zone.
 		$records = $app->db->queryAllRecords("SELECT ftp_user_id FROM ftp_user WHERE parent_domain_id = '".intval($this->id)."'");
 		foreach($records as $rec) {
 			$app->db->datalogDelete('ftp_user','ftp_user_id',$rec['ftp_user_id']);
 		}
 		
 		// Delete all records that belog to this zone.
 		$records = $app->db->queryAllRecords("SELECT shell_user_id FROM shell_user WHERE parent_domain_id = '".intval($this->id)."'");
 		foreach($records as $rec) {
 			$app->db->datalogDelete('shell_user','shell_user_id',$rec['shell_user_id']);
 		}
         
         // Delete all records that belog to this zone.
         $records = $app->db->queryAllRecords("SELECT id FROM cron WHERE parent_domain_id = '".intval($this->id)."'");
         foreach($records as $rec) {
             $app->db->datalogDelete('cron','id',$rec['id']);
         }
+		
+		//* Delete all records that belog to this web.
+        $records = $app->db->queryAllRecords("SELECT id FROM cron WHERE parent_domain_id = '".intval($this->id)."'");
+        foreach($records as $rec) {
+            $app->db->datalogDelete('cron','id',$rec['id']);
+        }
+		
+		//* Delete all records that belog to this web
+        $records = $app->db->queryAllRecords("SELECT webdav_user_id FROM webdav_user WHERE parent_domain_id = '".intval($this->id)."'");
+        foreach($records as $rec) {
+            $app->db->datalogDelete('webdav_user','webdav_user_id',$rec['webdav_user_id']);
+        }
+		
+		//* Delete all web folders
+        $records = $app->db->queryAllRecords("SELECT web_folder_id FROM web_folder WHERE parent_domain_id = '".intval($this->id)."'");
+        foreach($records as $rec) {
+            //* Delete all web folder users
+			$records2 = $app->db->queryAllRecords("SELECT web_folder_user_id FROM web_folder_user WHERE web_folder_id = '".$rec['web_folder_id']."'");
+			foreach($records2 as $rec2) {
+				$app->db->datalogDelete('web_folder_user','web_folder_user_id',$rec2['web_folder_user_id']);
+        }
+			$app->db->datalogDelete('web_folder','web_folder_id',$rec['web_folder_id']);
+        }
 	}
 }
 
@@ -55,29 +55,52 @@
 		}
 		
-		// Delete all records that belog to this zone.
+		//* Delete all records that belog to this web.
 		$records = $app->db->queryAllRecords("SELECT shell_user_id FROM shell_user WHERE parent_domain_id = '".intval($this->id)."'");
 		foreach($records as $rec) {
@@ -55,29 +55,52 @@
 		}
         
-        // Delete all records that belog to this zone.
+        //* Delete all records that belog to this web.
         $records = $app->db->queryAllRecords("SELECT id FROM cron WHERE parent_domain_id = '".intval($this->id)."'");
         foreach($records as $rec) {

--
Gitblit v1.9.1